create table PLANTS(
 PLANT_ID  number(*, 0) not null primary key,
 NAME      varchar2(255),
 FIRM_ID   number(*, 0),
 CLI_KIND  number(*, 0),
 SCHEM_ID  number(*, 0),
 GDOORS    LONG RAW)
STORAGE(INITIAL 1M NEXT 1M MINEXTENTS 1 MAXEXTENTS UNLIMITED
);
insert into PLANTS(PLANT_ID, NAME, FIRM_ID) values (0, ' ', 0);

create table TabOper(
 OPER_ID  number(*, 0) not null primary key,
 F_NAME   varchar2(64),
 S_NAME   varchar2(64),
 M_NAME   varchar2(64),
 Nickname varchar2(25) not null unique,
 PRIV     varchar2(255),
 PASSW    varchar2(255),
 SA       char(1),
 PLANT_ID number(*, 0)
);
insert into TabOper(OPER_ID,Nickname,PRIV,PASSW,SA) values (1,'admin','0119113600241e3f123a1620141e1e16270b3103250e2a003d1f8996','',1);
create sequence SEQ_TabOper start with 2;

CREATE TABLE DEPARTMENT(
 CODE       number(*, 0) not null primary key,
 FULL_NAME  varchar2(255),
 NAME       varchar2(64) not null,
 CYPHER     varchar2(10),
 DATE_START DATE,
 DATE_END   DATE,
 COD_KONT   number(*, 0),
 R_IN       number(4, 0),
 P_IN       number(4, 0),
 R_OUT      number(4, 0),
 P_OUT      number(4, 0),
 MAX_AB     number(4, 0),
 LEVEL_KD   number(3,0),
 PLANT_ID   number(*,0),
 LINK_COD   number(*, 0),
 DOORS      LONG RAW)
STORAGE(INITIAL 1M NEXT 1M MINEXTENTS 1 MAXEXTENTS UNLIMITED
);

CREATE TABLE PROFESSION(
 PROFESSION_ID number(*, 0) not null primary key,
 FULL_NAME     varchar2(100),
 NAME          varchar2(64) not null,
 CYPHER        varchar2(10),
 PLANT_ID      number(*,0),
 LINK_COD      number(*, 0),
 DATE_START    DATE,
 DATE_END      DATE
);

create sequence SEQ_DEPJOB;

CREATE TABLE STRUCTURE(
 CHILD_ID      number(*, 0)  NOT NULL,
 PARENT_ID     number(*, 0),
 POS           number(5, 0),
 PLANT_ID      number(*,0)
);

create table STATE(
CODE          number(*, 0) not null primary key,
COD_DEP       number(*, 0) not null,
PROFESSION_ID number(*, 0) not null,
LEVEL_KD      number(3,0),
COD_KONT      number(*, 0),
R_IN          number(4, 0),
P_IN          number(4, 0),
R_OUT         number(4, 0),
P_OUT         number(4, 0),
MAX_AB        number(4, 0),
DOORS         LONG RAW)
STORAGE(INITIAL 1M NEXT 1M MINEXTENTS 1 MAXEXTENTS UNLIMITED
);

create sequence SEQ_STATE;

CREATE or REPLACE trigger TR_STATE_CODE
BEFORE INSERT ON STATE
FOR EACH ROW
BEGIN
 select SEQ_STATE.NEXTVAL into :new.code from DUAL;
END;
/

CREATE TABLE AlienOrg(
 ORG_ID     number(*, 0) not null primary key,
 NAME       varchar2(64) not null,
 DOORS      LONG RAW,
 CLI_KIND   number(*, 0),
 DATE_START DATE,
 DATE_END   DATE,
 LEVEL_KD number(3,0))
STORAGE(INITIAL 1M NEXT 1M MINEXTENTS 1 MAXEXTENTS UNLIMITED
);
create sequence SEQ_AlienOrg start with 1;

CREATE TABLE PERSONNEL(
 USER_ID       number(*, 0)  not null primary key,
 INDICATION    CHAR(1)  default 0 not null,
 CLI_N         number(*, 0),
 F_NAME        varchar2(64),
 S_NAME        varchar2(64),
 M_NAME        varchar2(64),
 PLANT_ID      number(*, 0),
 DEPARTMENT_ID number(*, 0),
 PROFESSION_ID number(*, 0),
 ORG_ID        number(*, 0),
 JOB           varchar2(64),
 TABN          varchar2(32),
 TABN_REAL     varchar2(32),
 NUM           varchar2(32),
 CLI_KIND      number(*, 0),
 W_PHONE       varchar2(10),
 DATE_BRS      DATE,
 H_ADDR        varchar2(64),
 H_PHONE       varchar2(10),
 M_PHONE       varchar2(20),
 P_NUM         varchar2(50),
 P_ISSUED      varchar2(50),
 P_ISSUEDAY    DATE,
 REGISTRATION  varchar2(100),
 LEVEL_KD      number(*, 0),
 CARD_STS      number(1,0),
 GettingDATE   DATE,
 LOST_KD       varchar2(2),
 Decision      varchar2(100),
 Black_LIst    char(1),
 NumSchem      number(*, 0),
 VIP           char(1),
 ITR           char(1) default 0,
 POL           char(1) default 0,
 LINK_COD      varchar2(50))
  STORAGE(INITIAL 1M NEXT 1M MINEXTENTS 1 MAXEXTENTS UNLIMITED
);

create sequence SEQ_PERSONNEL start with 1;
create index PERS_IDX_CLIN on PERSONNEL(CLI_N);
create index PERS_IDX_LINK on PERSONNEL(LINK_COD);

CREATE TABLE PERSONNEL_PHOTOS(
 USER_ID number(*, 0) not null unique,
 PHOTO   BLOB)
  STORAGE(INITIAL 10M NEXT 10M MINEXTENTS 1 MAXEXTENTS UNLIMITED
);

CREATE TABLE HIST_PCARD(
 HIST_ID      number(*, 0) not null primary key,
 USER_ID      number(*, 0) not null CONSTRAINT fk_huser REFERENCES PERSONNEL(USER_ID) on delete cascade,
 CLI_N        number(*, 0),
 DATE_START   DATE,
 CARD_STS     number(1,0) not null,
 DATE_END     DATE,
 REASON       CHAR(1),
 FIO_OPER     varchar2(70) ,
 FIO_OPER_End varchar2(70) 
);
create sequence SEQ_HIST_PCARD start with 1;

alter table CLITYPES add INDICATION CHAR(1);

CREATE TABLE OperFactors(
 TypeGuest        number(*, 0),
 NameGuest        varchar2(64),
 ErrStatus        varchar2(40),
 DoUpdate         char(1),
 LastMajVersion   number(2,0),
 LastMinVersion   number(2,0),
 LastRelease      number(3,0),
 LastBuild        number(*, 0),
 LastBuildReq     number(*, 0),
 GDOORS           LONG RAW,
 CliGuest         char(1),
 GuestLevel       number(2,0),
 FullDep          char(1) default 0,
 NewVersionPass   varchar2(255),
 NewRequestPass   varchar2(255),
 VisReq           char(1) default 0,
 GetImit          char(1) default 0,
 ShowNotice       char(1),
 GUEST_START      date,
 GUEST_END        date,
 FNumProp         number(1, 0)
);

create sequence SEQ_GuestCard start with 1;

create table  PERS_HISTORY(
 CODE          number(*, 0) not null primary key,
 USER_ID       number(*, 0) not null CONSTRAINT fk_phist REFERENCES PERSONNEL(USER_ID) on delete cascade,
 DATE_START    date not null,
 DATE_END      date, 
 DEPARTMENT_ID number(*, 0),
 PROFESSION_ID number(*, 0),
 PLANT_ID      number(*, 0),
 REASON        number(2, 0),
 NAKAZ         varchar2(50)
);

create sequence SEQ_HISTORY;
CREATE INDEX CLI_HIST on PERS_HISTORY(USER_ID);

create table DEPCH(
U_ID          number(*, 0),
DEPARTMENT_ID number(*, 0));

commit;

alter table VISITORS add PASSPORT varchar2(128);
alter table VISITORS add WRPHONE CHAR(1);
alter table VISITORS add COMM varchar2(255);
alter table VISITORS add PLANT_ID number(*,0);
CREATE INDEX VIS_FIND on VISITORS(FAMNAME);

alter table CARDLOG add Nickname varchar2(25);
alter table CARDLOG add DEPARTMENT_ID number(*, 0);
alter table CARDLOG add ORG_ID number(*, 0);
alter table CARDLOG add DT_RETURN date;
alter table CARDLOG add FIO_OPER_RETURN varchar2(180);
alter table CARDLOG add COMP varchar2(50);
alter table CARDLOG add COMP_RETURN varchar2(50);
alter table CARDLOG add WRPHONE CHAR(1);
alter table CARDLOG add COMM varchar2(255);
alter table CARDLOG add BLANK number(*, 0);
alter table CARDLOG add FIO_Z varchar2(195);
alter table CARDLOG add PLANT_ID number(*,0);

CREATE TABLE BP_REQUEST(
  N          number(*, 0) not null primary key,
  Give_DT    DATE,
  Date_Start Date,
  Date_End   Date,
  F_NAME     varchar2(64),
  S_NAME     varchar2(64),
  M_NAME     varchar2(64),
  N_ORG      varchar2(100),
  JOB        varchar2(100),
  PASSPORT   varchar2(128),
  WRPHONE    varchar2(1),
  APPLIER    number(*, 0),
  INDICATION CHAR(1),
  APPDEPT    number(*, 0),
  Use_DT     DATE,
  PLANT_ID   number(*, 0),
  OPERID     number(*, 0),
  Nickname   varchar2(25),
  COMM       varchar2(255),
  VIS        char(1) default 0,
  Repeated   number(1, 0) default 0
);
create sequence SEQ_BPREQ start with 1;
CREATE INDEX BP_VIS on BP_REQUEST(F_NAME, N_ORG);
CREATE INDEX BP_DT on BP_REQUEST(DATE_START);

CREATE TABLE BP_BLACK_LIST(
  N          number(*, 0) not null primary key,
  DT         Date,
  F_NAME     varchar2(64),
  S_NAME     varchar2(64),
  M_NAME     varchar2(64),
  N_ORG      varchar2(100),
  JOB        varchar2(100),
  PASSPORT   varchar2(128),
  Nickname   varchar2(25),
  COMM       varchar2(255),
  USER_ID    number(*, 0),
  VST_ID     number(*, 0),
  PLANT_ID   number(*, 0)
);
create sequence SEQ_BPBLACK start with 1;

CREATE or replace TRIGGER TR_BPBlack_N
BEFORE INSERT ON BP_Black_List
FOR EACH ROW
BEGIN
 select SEQ_BPBlack.NEXTVAL into :new.N from DUAL;
END;
/

--      
create table RENEWREQ (
  CD number(1,0)
);

--  sequence SEQ_BP_NUM    
create sequence SEQ_BP_NUM;

--     - 

create table MODEL_BOOK (
 CODE number(*, 0) not null primary key,
 NAME varchar2(64) not null
);
insert into MODEL_BOOK(CODE,NAME) values (1,'');
insert into MODEL_BOOK(CODE,NAME) values (2,'');
insert into MODEL_BOOK(CODE,NAME) values (3,'');
insert into MODEL_BOOK(CODE,NAME) values (4,'');
insert into MODEL_BOOK(CODE,NAME) values (5,'');
insert into MODEL_BOOK(CODE,NAME) values (6,'');
insert into MODEL_BOOK(CODE,NAME) values (7,'');

create table AUTO_BOOK (
 CODE       number(*, 0) not null primary key,
 NUM        varchar2(20),
 TP         CHAR(1) default 1,
 CLI_N      number(*, 0),
 F_NAME     varchar2(64),
 S_NAME     varchar2(64),
 M_NAME     varchar2(64),
 PASSPORT   varchar2(100),
 FIO_OWN    varchar2(180), 
 BLACK_LIST char(1) default 0,
 PLANT_ID   number(*, 0),
 ORG_ID     number(*, 0),
 COD_PART   number(*, 0),
 COD_MOD    number(*, 0) CONSTRAINT fk_automod REFERENCES MODEL_BOOK(CODE)
);
CREATE sequence SEQ_AUTO start with 8;


create table FREIGHT_BOOK (
 CODE  number(*, 0) not null primary key,
 NAME  varchar2(64) not null,
 UNITS varchar2(10)
);
CREATE sequence SEQ_FREIGHT start with 1;

create table TYPE_DOC (
 CODE  number(*, 0) not null primary key,
 NAME  varchar2(64) not null
);
insert into TYPE_DOC(CODE,NAME) values (1,'');
insert into TYPE_DOC(CODE,NAME) values (2,'');
insert into TYPE_DOC(CODE,NAME) values (3,'');
insert into TYPE_DOC(CODE,NAME) values (4,' ');
CREATE sequence SEQ_TDOC start with 5;

create table PARTNERS_BOOK (
 CODE      number(*, 0) not null primary key,
 NAME      varchar2(64) not null,
 FULL_NAME varchar2(255),
 ADDRESS   varchar2(255),
 EDRPO     varchar2(25),
 RS        varchar2(30),
 MFO       varchar2(12),
 BANK      varchar2(100),
 NDS       varchar2(30),
 PHONES    varchar2(255),
 COMM      varchar2(255) 
);
CREATE sequence SEQ_PARTNERS start with 1;

create table CARDLOG_AUTO (
 CODE            number(*, 0) not null primary key,
 DT              DATE,
 TP              CHAR(1),
 NUM             varchar2(20) not null,
 MARK            varchar2(64),
 CLI_N           number(*, 0),
 CARDCODE        number(*, 0),
 number_         varchar2(11),
 FIO_DR          varchar2(180),
 FIO_OWN         varchar2(180), 
 BRUTTO          number(12,4),
 NETTO           number(12,4),
 PACK            number(12,4),
 ORG_ID          number(*, 0),
 COD_PART        number(*, 0) CONSTRAINT fk_logpart REFERENCES PARTNERS_BOOK(CODE),
 TRAILER         varchar2(20),
 PURPOSE         varchar2(64),
 PLANT_ID        number(*, 0),
 DT_START        DATE,
 DT_END          DATE,
 DT_RETURN       DATE,
 FIO_OPER        varchar2(180),
 FIO_OPER_RETURN varchar2(180),
 COMP            varchar2(50),
 KPP             varchar2(50),
 COMP_RETURN     varchar2(50),
 KPP_RETURN      varchar2(50),
 REASON          varchar2(100),
 SCHEME          varchar2(50),
 BLANK           number(*, 0),
 COMM            varchar2(255),
 COMM_RETURN     varchar2(255) 
);
CREATE sequence SEQ_LOGAUTO start with 1;
CREATE INDEX ALOG_NUM on CARDLOG_AUTO(NUM);

--  sequence SEQ_AUTO_BP_NUM     
CREATE sequence SEQ_AUTO_BP_NUM;

create table IMP_EXP_FREIGHT (
 CODE          number(*, 0) not null primary key,
 TP            CHAR(1),
 DT            DATE not null,
 NUM_AUTO      varchar2(20) not null,
 COD_MOD       number(*, 0) CONSTRAINT fk_iemod REFERENCES MODEL_BOOK(CODE),
 NUM_CARD      varchar2(20),
 CLI_N         number(*, 0),
 FIO_DR        varchar2(180),
 FIO_FORW      varchar2(180),
 COD_TYPE      number(*, 0) CONSTRAINT fk_tpie REFERENCES TYPE_DOC(CODE),
 NUM_DOC       varchar2(100),
 COD_PART      number(*, 0) CONSTRAINT fk_partie REFERENCES PARTNERS_BOOK(CODE),
 DEPARTMENT_ID number(*, 0),
 ORG_ID        number(*, 0),
 PLANT_ID      number(*, 0),
 BRUTTO        number(12,4),
 NETTO         number(12,4),
 PACK          number(12,4),
 COMM          varchar2(255),
 FIO_OPER      varchar2(180),
 KPP           varchar2(50),
 COMP          varchar2(50),
 RATIFY        char(1) default 0
);
CREATE sequence SEQ_IMP_EXP start with 1;
CREATE INDEX IMPEXP_DT on IMP_EXP_FREIGHT(DT);
CREATE INDEX IMPEXP_NUM on IMP_EXP_FREIGHT(NUM_AUTO);

create table POS_IMPEXP (
 CODE      number(*, 0) not null primary key,
 COD_IE    number(*, 0) CONSTRAINT fk_posie REFERENCES IMP_EXP_FREIGHT(CODE) on delete cascade,
 COD_FR    number(*, 0) CONSTRAINT fk_frtie REFERENCES FREIGHT_BOOK(CODE),
 QUANTITY  number(12,4)
);
CREATE sequence SEQ_POS_IMPEXP start with 1;

create table KPP (
 CODE  number(*, 0) not null primary key,
 COMP  varchar2(50) not null unique,
 NUM   varchar2(50) 
); 
CREATE sequence SEQ_KPP start with 1;

create table SCHEME_KPP (
 CODE      number(*, 0) not null primary key,
 NAME      varchar2(64) not null,
 LEVEL_KD  number(3,0),
 PLANT_ID  number(*, 0),
 DOORS     LONG RAW)
STORAGE(INITIAL 1M NEXT 1M MINEXTENTS 1 MAXEXTENTS UNLIMITED
); 

create table SCHEME_KPP_STR (
 COD_SCH  number(*, 0) CONSTRAINT fk_schstr REFERENCES SCHEME_KPP(CODE) on delete cascade,
 COD_KPP  number(*, 0) CONSTRAINT fk_kpp REFERENCES KPP(CODE),
 constraint KPP_SCH unique (COD_SCH,COD_KPP)
);

CREATE TABLE AUTO_BLACK_LIST(
  CODE       number(*, 0) not null primary key,
  COD_AUTO   number(*, 0),
  NUM        varchar2(20),
  MARK       varchar2(64),
  FIO_OWN    varchar2(180),
  DT         Date,
  FIO_OPER   varchar2(180),
  COMM       varchar2(255)  
);
create sequence SEQ_AUTOBLACK start with 1;

commit;

create table GUEST_PARAM (
 CLI_KIND number(*, 0) not null primary key,
 LEVEL_KD number(3,0)
);

CREATE TABLE CARD_RETURN(
 SNSN      number(*, 0) not null UNIQUE,
 EV_N      number(*, 0) not null
);

alter table CLITAB add CELLPOSITION varchar2(15);
alter table CLITYPES add PREFCARD varchar2(2);
alter table PERSONNEL add CELLPOSITION varchar2(15);
alter table HIST_PCARD add CELLPOSITION varchar2(15);

create table GEN_NUMCARD(
 CLI_KIND NUMBER(*,0) not null unique,
 LASTNUM  NUMBER(*,0) not null
);

create table HIST_USER(
 CODE         number(*, 0) not null primary key,
 DT           date,
 COD_EVENT    number(3,0) not null,
 NUM_KD       varchar2(8),
 USER_ID      number(*, 0),
 FIO_USER     varchar2(200),
 UIN          varchar2(32),
 AUTO_NUM     varchar2(70),
 FIO_OPER     varchar2(70),
 EVENT_       varchar2(255),
 COMM         varchar2(255)
);
create sequence SEQ_Hist_User;
create index IHID_USER on HIST_USER(USER_ID);
create index IHFIO_USER on HIST_USER(FIO_USER);
create index IHNUM_KD on HIST_USER(NUM_KD);

create table PERS_AUTOCARD(
 CODE        number(*, 0) not null primary key,
 USER_ID     number(*, 0) not null CONSTRAINT fk_hauser REFERENCES PERSONNEL(USER_ID) on delete cascade,
 AUTO_NUM    varchar2(20),
 FIO_OWN     varchar2(180), 
 COD_MOD     number(*, 0) CONSTRAINT fk_amod REFERENCES MODEL_BOOK(CODE),
 TP          CHAR(1) default 0,
 CLI_KIND    number(*, 0),
 CLI_N       number(*, 0),
 LEVEL_KD    number(*, 0),
 CARD_STS    number(1,0),
 GettingDATE DATE,
 NumSchem    number(*, 0),
 COMM        varchar2(255)
);
create sequence SEQ_PERS_ACARD start with 1;


create table HIST_ACARD(
 HIST_ID      number(*, 0) not null primary key,
 USER_ID      number(*, 0) not null CONSTRAINT fk_histacard REFERENCES PERSONNEL(USER_ID) on delete cascade,
 CLI_N        number(*, 0),
 DATE_START   DATE,
 CARD_STS     number(1,0) not null,
 DATE_END     DATE,
 REASON       CHAR(1),
 FIO_OPER     varchar2(70),
 FIO_OPER_End varchar2(70) 
);
create sequence SEQ_HIST_ACARD start with 1;

commit;

exit;